@@ -95,7 +95,7 @@
 #define HAVE_TIME_H 1
 #define HAVE_UNISTD_H 1
 #define HAVE_UTIME_H 1
-/* #undef HAVE_VARARGS_H */
+#define HAVE_VARARGS_H 1
 /* #undef HAVE_SYS_UTIME_H */
 #define HAVE_SYS_WAIT_H 1
 #define HAVE_SYS_PARAM_H 1
@@ -331,7 +331,7 @@
     #define WORDS_BIGENDIAN 1
   #endif
 #else
-/* #undef WORDS_BIGENDIAN */
+#define WORDS_BIGENDIAN 1 
 #endif
 
 /* Define to `__inline__' or `__inline' if that's what the C compiler calls
@@ -392,8 +392,8 @@
 #define STACK_DIRECTION -1
 
 #define SYSTEM_TYPE "OpenBSD"
-#define MACHINE_TYPE "amd64"
-#define DEFAULT_MACHINE "amd64"
+#define MACHINE_TYPE "sparc64"
+#define DEFAULT_MACHINE "sparc64"
 /* #undef HAVE_DTRACE */
 
 #define SIGNAL_WITH_VIO_CLOSE 1
@@ -528,16 +528,16 @@
 
 #define MYSQL_VERSION_MAJOR 10
 #define MYSQL_VERSION_MINOR 5
-#define MYSQL_VERSION_PATCH 10
+#define MYSQL_VERSION_PATCH 11
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.5.10"
+#define PACKAGE_STRING "MySQL Server 10.5.11"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.5.10"
-#define VERSION "10.5.10"
+#define PACKAGE_VERSION "10.5.11"
+#define VERSION "10.5.11"
 #define PROTOCOL_VERSION 10
 #define PCRE2_CODE_UNIT_WIDTH 8
 
